==> AxolotlClient-3.1.6%2B1.21.10-sources.jar: io/github/axolotlclient/bridge/mixin/resource/ResourceManagerMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.bridge.mixin.resource;


import java.io.IOException;
import java.util.Map;
import java.util.function.Predicate;
import net.minecraft.class_2960;
import net.minecraft.class_3298;
import net.minecraft.class_3300;
import net.minecraft.class_5912;
import io.github.axolotlclient.bridge.resource.AxoResource;
import io.github.axolotlclient.bridge.resource.AxoResourceManager;
import io.github.axolotlclient.bridge.util.AxoIdentifier;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_3300.class)
public interface ResourceManagerMixin extends class_5912, AxoResourceManager {

	@Shadow
	Map<class_2960, class_3298> listResources(String path, Predicate<class_2960> filter);

	@SuppressWarnings("unchecked")
	@Override
	default Map<AxoIdentifier, AxoResource> br$listResources(String namespace, String prefix, Predicate<AxoIdentifier> filter) {
		// this cast is maybe not ideal
		return (Map<AxoIdentifier, AxoResource>) (Object) listResources(prefix, filter::test);
	}

	@Override
	default AxoResource br$getResource(AxoIdentifier loc) throws IOException {
		return getResourceOrThrow((class_2960) loc);
	}
}

==> AxolotlClient-3.1.8%2B1.21.1-sources.jar: io/github/axolotlclient/bridge/mixin/resource/ResourceManagerMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.bridge.mixin.resource;


import java.io.IOException;
import java.util.Map;
import java.util.function.Predicate;
import net.minecraft.class_2960;
import net.minecraft.class_3298;
import net.minecraft.class_3300;
import net.minecraft.class_5912;
import io.github.axolotlclient.bridge.resource.AxoResource;
import io.github.axolotlclient.bridge.resource.AxoResourceManager;
import io.github.axolotlclient.bridge.util.AxoIdentifier;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_3300.class)
public interface ResourceManagerMixin extends class_5912, AxoResourceManager {

	@Shadow
	Map<class_2960, class_3298> findResources(String par1, Predicate<class_2960> par2);

	@SuppressWarnings("unchecked")
	@Override
	default Map<AxoIdentifier, AxoResource> br$listResources(String namespace, String prefix, Predicate<AxoIdentifier> filter) {
		// this cast is maybe not ideal
		return (Map<AxoIdentifier, AxoResource>) (Object) findResources(prefix, filter::test);
	}

	@Override
	default AxoResource br$getResource(AxoIdentifier loc) throws IOException {
		return getResourceOrThrow((class_2960) loc);
	}
}
